@@ -1,10 +1,10 @@
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2010 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2008-2015 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -13,15 +13,11 @@
 //  GNU General Public License for more details.
 //
 //  You should have received a copy of the GNU General Public License
-//  along with this program; if not, write to the Free Software
-//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 //
-// ----------------------------------------------------------------------
+// ----------------------------------------------------------------------------
 
 
-#include <cairo/cairo.h>
-#include <cairo/cairo-xlib.h>
-#include <math.h>
 #include "button.h"
 
 
@@ -31,19 +27,19 @@ int PushButton::_button = 0;
 
 PushButton::PushButton (X_window     *parent,
                         X_callback   *cbobj,
-                        ButtonImg    *image,
+			int           cbind,
+                        XImage       *image,
 		        int  xp,
                         int  yp,
-                        int  cbind) :
-
-    X_window (parent,
-              image->_x0 + xp, image->_y0 + yp,
-              image->_dx, image->_dy,
-              image->_backg->pixel),
+			int  xs,
+			int  ys) :
+    X_window (parent, xp, yp, xs, ys, 0),
     _cbobj (cbobj),
     _cbind (cbind),
     _image (image),
-    _state (0)
+    _state (0),
+    _xs (xs),
+    _ys (ys)
 {
     x_add_events (ExposureMask | ButtonPressMask | ButtonReleaseMask);
 } 
@@ -128,8 +124,8 @@ void PushButton::set_state (int s)
 
 void PushButton::render (void)
 {
-    XPutImage (dpy (), win (), dgc (), _image->_ximage,
-               _image->_x0, _image->_y0 + _state * _image->_dy, 0, 0, _image->_dx, _image->_dy);
+    XSetFunction (dpy (), dgc (), GXcopy);
+    XPutImage (dpy (), win (), dgc (), _image, 0, _state * _ys, 0, 0, _xs, _ys);
 }
 
 
